@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL$
-#     $Date$
-#   $Author$
-# $Revision$
-##############################################################################
-
 package Perl::Critic::Policy::BuiltinFunctions::ProhibitLvalueSubstr;
 
 use 5.006001;
@@ -16,7 +9,7 @@ use version 0.77 ();
 use Perl::Critic::Utils qw{ :severities :classification :language };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.121';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -48,7 +41,7 @@ sub prepare_to_scan_document {
 sub violates {
     my ($self, $elem, undef) = @_;
 
-    return if $elem ne 'substr';
+    return if $elem->content() ne 'substr';
     return if ! is_function_call($elem);
 
     my $sib = $elem;
