@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/BuiltinFunctions/ProhibitReverseSortBlock.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Policy::BuiltinFunctions::ProhibitReverseSortBlock;
 
 use 5.006001;
@@ -15,11 +8,11 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities :classification };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.088';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
-Readonly::Scalar my $DESC => q{Forbid $b before $a in sort blocks}; ## no critic (Interpolation)
+Readonly::Scalar my $DESC => q{Forbid $b before $a in sort blocks}; ## no critic (InterpolationOfMetachars)
 Readonly::Scalar my $EXPL => [ 152 ];
 
 #-----------------------------------------------------------------------------
@@ -34,7 +27,7 @@ sub applies_to           { return 'PPI::Token::Word'    }
 sub violates {
     my ($self, $elem, $doc) = @_;
 
-    return if $elem ne 'sort';
+    return if $elem->content() ne 'sort';
     return if ! is_function_call($elem);
 
     my $sib = $elem->snext_sibling();
@@ -66,8 +59,7 @@ sub violates {
                 $count--;
                 if ($count < 0) {
                     # Found too many C<$b>s too early
-                    my $sev = $self->get_severity();
-                    return $self->violation( $DESC, $EXPL, $elem, $sev );
+                    return $self->violation( $DESC, $EXPL, $elem );
                 }
             }
         }
@@ -87,24 +79,26 @@ __END__
 
 Perl::Critic::Policy::BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks.
 
+
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
 
-Conway says that it is much clearer to use C<reverse> than to flip C<$a> and
-C<$b> around in a C<sort> block.  He also suggests that, in newer perls,
-C<reverse> is specifically looked for and optimized, and in the case of a
-simple reversed string C<sort>, using C<reverse> with a C<sort> with no block
-is faster even in old perls.
+Conway says that it is much clearer to use C<reverse> than to flip
+C<$a> and C<$b> around in a C<sort> block.  He also suggests that, in
+newer perls, C<reverse> is specifically looked for and optimized, and
+in the case of a simple reversed string C<sort>, using C<reverse> with
+a C<sort> with no block is faster even in old perls.
 
-  my @foo = sort { $b cmp $a } @bar;         #not ok
-  my @foo = reverse sort @bar;               #ok
+    my @foo = sort { $b cmp $a } @bar;         #not ok
+    my @foo = reverse sort @bar;               #ok
 
-  my @foo = sort { $b <=> $a } @bar;         #not ok
-  my @foo = reverse sort { $a <=> $b } @bar; #ok
+    my @foo = sort { $b <=> $a } @bar;         #not ok
+    my @foo = reverse sort { $a <=> $b } @bar; #ok
 
 
 =head1 CONFIGURATION
@@ -116,9 +110,10 @@ This Policy is not configurable except for the standard options.
 
 Chris Dolan <cdolan@cpan.org>
 
+
 =head1 COPYRIGHT
 
-Copyright (C) 2006 Chris Dolan.  All rights reserved.
+Copyright (c) 2006-2011 Chris Dolan.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
