@@ -1,21 +1,15 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/ControlStructures/ProhibitCascadingIfElse.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Policy::ControlStructures::ProhibitCascadingIfElse;
 
 use 5.006001;
 use strict;
 use warnings;
+
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.088';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -56,7 +50,7 @@ sub violates {
 sub _count_elsifs {
     my $elem = shift;
     return
-      grep { $_->isa('PPI::Token::Word') && $_ eq 'elsif' } $elem->schildren();
+      grep { $_->isa('PPI::Token::Word') && $_->content() eq 'elsif' } $elem->schildren();
 }
 
 1;
@@ -75,47 +69,49 @@ Perl::Critic::Policy::ControlStructures::ProhibitCascadingIfElse - Don't write l
 
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
 
 Long C<if-elsif> chains are hard to digest, especially if they are
 longer than a single page or screen.  If testing for equality, use a
-hash lookup instead.  See L<Switch> for another approach.
+hash lookup instead.  If you're using perl 5.10 or later, use
+C<given>/C<when>.
 
-  if ($condition1) {         #ok
-      $foo = 1;
-  }
-  elsif ($condition2) {      #ok
-      $foo = 2;
-  }
-  elsif ($condition3) {      #ok
-      $foo = 3;
-  }
-  elsif ($condition4) {      #too many!
-      $foo = 4;
-  }
-  else {                     #ok
-      $foo = $default;
-  }
+    if ($condition1) {         #ok
+        $foo = 1;
+    }
+    elsif ($condition2) {      #ok
+        $foo = 2;
+    }
+    elsif ($condition3) {      #ok
+        $foo = 3;
+    }
+    elsif ($condition4) {      #too many!
+        $foo = 4;
+    }
+    else {                     #ok
+        $foo = $default;
+    }
 
 =head1 CONFIGURATION
 
-This policy can be configured with a maximum number of C<elsif> alternatives
-to allow.  The default is 2.  This can be specified via a C<max_elsif> item in
-the F<.perlcriticrc> file:
+This policy can be configured with a maximum number of C<elsif>
+alternatives to allow.  The default is 2.  This can be specified via a
+C<max_elsif> item in the F<.perlcriticrc> file:
 
- [ControlStructures::ProhibitCascadingIfElse]
- max_elsif = 3
+    [ControlStructures::ProhibitCascadingIfElse]
+    max_elsif = 3
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
