@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/RegularExpressions/RequireBracesForMultiline.pm $
-#     $Date: 2009-03-07 09:14:51 -0600 (Sat, 07 Mar 2009) $
-#   $Author: clonezone $
-# $Revision: 3231 $
-##############################################################################
-
 package Perl::Critic::Policy::RegularExpressions::RequireBracesForMultiline;
 
 use 5.006001;
@@ -16,10 +9,10 @@ use English qw(-no_match_vars);
 use Carp;
 
 use Perl::Critic::Utils qw{ :booleans :severities };
-use Perl::Critic::Utils::PPIRegexp qw{ get_match_string get_delimiters };
+
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.098';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -67,10 +60,10 @@ sub initialize_if_enabled {
 sub violates {
     my ( $self, $elem, undef ) = @_;
 
-    my $re = get_match_string($elem);
+    my $re = $elem->get_match_string();
     return if $re !~ m/\n/xms;
 
-    my ($match_delim) = get_delimiters($elem);
+    my ($match_delim) = $elem->get_delimiters();
     return if $self->{_allowed_delimiters}{$match_delim};
 
     return $self->violation( $DESC, $EXPL, $elem );
@@ -145,7 +138,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009 Chris Dolan.  Many rights reserved.
+Copyright (c) 2007-2011 Chris Dolan.  Many rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
