@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Subroutines/ProhibitNestedSubs.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Policy::Subroutines::ProhibitNestedSubs;
 
 use 5.006001;
@@ -15,7 +8,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.088';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -36,7 +29,15 @@ sub applies_to           { return 'PPI::Statement::Sub' }
 sub violates {
     my ($self, $elem, $doc) = @_;
 
-    my $inner = $elem->find_first('PPI::Statement::Sub');
+    return if $elem->isa('PPI::Statement::Scheduled');
+
+    my $inner = $elem->find_first(
+        sub {
+            return
+                    $_[1]->isa('PPI::Statement::Sub')
+                &&  ! $_[1]->isa('PPI::Statement::Scheduled');
+        }
+    );
     return if not $inner;
 
     # Must be a violation...
@@ -59,7 +60,8 @@ Perl::Critic::Policy::Subroutines::ProhibitNestedSubs - C<sub never { sub correc
 
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
@@ -76,9 +78,8 @@ This does not do what you think:
       ...
   }
 
-C<do_subprocess()> is global, despite where it is declared.
-Either write your subs without nesting or use anonymous code
-references.
+C<do_subprocess()> is global, despite where it is declared.  Either
+write your subs without nesting or use anonymous code references.
 
 
 
@@ -89,7 +90,7 @@ This Policy is not configurable except for the standard options.
 
 =head1 NOTE
 
-Originally part of L<Perl::Critic::Tics>.
+Originally part of L<Perl::Critic::Tics|Perl::Critic::Tics>.
 
 
 =head1 AUTHOR
@@ -98,10 +99,10 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008 Ricardo SIGNES.
+Copyright (c) 2007-2011 Ricardo SIGNES.
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
