@@ -1,12 +1,6 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Subroutines/ProhibitSubroutinePrototypes.pm $
-#     $Date: 2008-03-08 10:09:46 -0600 (Sat, 08 Mar 2008) $
-#   $Author: clonezone $
-# $Revision: 2163 $
-##############################################################################
-
 package Perl::Critic::Policy::Subroutines::ProhibitSubroutinePrototypes;
 
+use 5.006001;
 use strict;
 use warnings;
 use Readonly;
@@ -14,7 +8,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.082';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -25,7 +19,7 @@ Readonly::Scalar my $EXPL => [ 194 ];
 
 sub supported_parameters { return ()                    }
 sub default_severity     { return $SEVERITY_HIGHEST     }
-sub default_themes       { return qw(core pbp bugs)     }
+sub default_themes       { return qw(core pbp bugs certrec )     }
 sub applies_to           { return 'PPI::Statement::Sub' }
 
 #-----------------------------------------------------------------------------
@@ -48,20 +42,32 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Subroutines::ProhibitSubroutinePrototypes
+Perl::Critic::Policy::Subroutines::ProhibitSubroutinePrototypes - Don't write C<sub my_function (@@) {}>.
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
+
 
 =head1 DESCRIPTION
 
 Contrary to common belief, subroutine prototypes do not enable
 compile-time checks for proper arguments.  Don't use them.
 
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
+
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -76,4 +82,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
