@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitNoisyQuotes.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitNoisyQuotes;
 
 use 5.006001;
@@ -15,11 +8,11 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.088';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
-Readonly::Scalar my $NOISE_RX => qr{\A ["|']  [^ \w () {} [\] <> ]{1,2}  ['|"] \z}mx;
+Readonly::Scalar my $NOISE_RX => qr{\A ["']  [^ \w () {} [\] <> ]{1,2}  ['"] \z}xms;
 Readonly::Scalar my $DESC     => q{Quotes used with a noisy string};
 Readonly::Scalar my $EXPL     => [ 53 ];
 
@@ -56,9 +49,11 @@ __END__
 
 Perl::Critic::Policy::ValuesAndExpressions::ProhibitNoisyQuotes - Use C<q{}> or C<qq{}> instead of quotes for awkward-looking strings.
 
+
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
@@ -66,19 +61,19 @@ This Policy is part of the core L<Perl::Critic> distribution.
 Don't use quotes for one or two-character strings of non-alphanumeric
 characters (i.e. noise).  These tend to be hard to read.  For
 legibility, use C<q{}> or a named value.  However, braces,
-parentheses, and brackets tend do to look better in quotes, so those
+parentheses and brackets tend to look better in quotes, so those
 are allowed.
 
-  $str = join ',', @list;     #not ok
-  $str = join ",", @list;     #not ok
-  $str = join q{,}, @list;    #better
+    $str = join ',', @list;     #not ok
+    $str = join ",", @list;     #not ok
+    $str = join q{,}, @list;    #better
 
-  $COMMA = q{,};
-  $str = join $COMMA, @list;  #best
+    $COMMA = q{,};
+    $str = join $COMMA, @list;  #best
 
-  $lbrace = '(';          #ok
-  $rbrace = ')';          #ok
-  print '(', @list, ')';  #ok
+    $lbrace = '(';          #ok
+    $rbrace = ')';          #ok
+    print '(', @list, ')';  #ok
 
 
 =head1 CONFIGURATION
@@ -88,15 +83,17 @@ This Policy is not configurable except for the standard options.
 
 =head1 SEE ALSO
 
-L<Perl::Critic::Policy::ValuesAndExpressions::ProhibitEmptyQuotes>
+L<Perl::Critic::Policy::ValuesAndExpressions::ProhibitEmptyQuotes|Perl::Critic::Policy::ValuesAndExpressions::ProhibitEmptyQuotes>
+
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
