@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/PolicyListing.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::PolicyListing;
 
 use 5.006001;
@@ -17,7 +10,7 @@ use Perl::Critic::Policy qw();
 
 use overload ( q<""> => 'to_string' );
 
-our $VERSION = '1.088';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -56,46 +49,61 @@ __END__
 
 Perl::Critic::PolicyListing - Display minimal information about Policies.
 
+
 =head1 DESCRIPTION
 
 This is a helper class that formats a set of Policy objects for
 pretty-printing.  There are no user-serviceable parts here.
 
+
+=head1 INTERFACE SUPPORT
+
+This is considered to be a non-public class.  Its interface is subject
+to change without notice.
+
+
 =head1 CONSTRUCTOR
 
-=over 8
+=over
 
 =item C<< new( -policies => \@POLICY_OBJECTS ) >>
 
 Returns a reference to a new C<Perl::Critic::PolicyListing> object.
 
+
 =back
 
+
 =head1 METHODS
 
-=over 8
+=over
 
 =item to_string()
 
 Returns a string representation of this C<PolicyListing>.  See
 L<"OVERLOADS"> for more information.
 
+
 =back
 
+
 =head1 OVERLOADS
 
-When a L<Perl::Critic::PolicyListing> is evaluated in string context,
-it produces a one-line summary of the default severity, policy name,
-and default themes for each L<Perl::Critic::Policy> object that was
-given to the constructor of this C<PolicyListing>.
+When a L<Perl::Critic::PolicyListing|Perl::Critic::PolicyListing> is
+evaluated in string context, it produces a one-line summary of the
+default severity, policy name, and default themes for each
+L<Perl::Critic::Policy|Perl::Critic::Policy> object that was given to
+the constructor of this C<PolicyListing>.
+
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
