@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Utils/McCabe.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Utils::McCabe;
 
 use 5.006001;
@@ -15,11 +8,11 @@ use Readonly;
 
 use Perl::Critic::Utils qw{ :data_conversion :classification };
 
-use base 'Exporter';
+use Exporter 'import';
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '1.088';
+our $VERSION = '1.126';
 
 #-----------------------------------------------------------------------------
 
@@ -75,7 +68,7 @@ sub _count_main_logic_operators_and_keywords {
         # Only count things that *are not* in a subroutine.  Returning an
         # explicit 'undef' here prevents PPI from descending into the node.
 
-        ## no critic Subroutines::ProhibitExplicitReturnUndef
+        ## no critic (ProhibitExplicitReturnUndef)
         return undef if $elem->isa('PPI::Statement::Sub');
 
 
@@ -149,16 +142,23 @@ __END__
 
 Perl::Critic::Utils::McCabe - Functions that calculate the McCabe score of source code.
 
+
 =head1 DESCRIPTION
 
 Provides approximations of McCabe scores.  The McCabe score of a set
 of code describes the number of possible paths through it.  The
 functions here approximate the McCabe score by summing the number of
 conditional statements and operators within a set of code.  See
-L<http://www.sei.cmu.edu/str/descriptions/cyclomatic_body.html> for
+L<http://en.wikipedia.org/wiki/Cyclomatic_complexity> for
 some discussion about the McCabe number and other complexity metrics.
 
 
+=head1 INTERFACE SUPPORT
+
+This is considered to be a public module.  Any changes to its
+interface will go through a deprecation cycle.
+
+
 =head1 IMPORTABLE SUBS
 
 =over
@@ -166,23 +166,26 @@ some discussion about the McCabe number and other complexity metrics.
 =item C<calculate_mccabe_of_sub( $sub )>
 
 Calculates an approximation of the McCabe number of the code in a
-L<PPI::Statement::Sub>.
+L<PPI::Statement::Sub|PPI::Statement::Sub>.
+
 
 =item C<calculate_mccabe_of_main( $doc )>
 
 Calculates an approximation of the McCabe number of all the code in a
-L<PPI::Statement::Document> that is B<not> contained in a subroutine.
+L<PPI::Statement::Document|PPI::Statement::Document> that is B<not>
+contained in a subroutine.
 
 =back
 
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
